==> haskell-incremental-parser-0.3.1.1-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.3.1.1
id: incremental-parser-0.3.1.1-I7US0wpvD2rF6h5zXRRyiu
key: incremental-parser-0.3.1.1-I7US0wpvD2rF6h5zXRRyiu
license: GPL-3.0-only
copyright: (c) 2011-2018 Mario Blazevic
maintainer: blamario@yahoo.com
author: Mario Blazevic
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
abi: c5a91be61756e5b5b7a3b5556edf1e3d
exposed: True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
import-dirs: /usr/lib/ghc-8.4.3/site-local/incremental-parser-0.3.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/incremental-parser-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/incremental-parser-0.3.1.1
hs-libraries: HSincremental-parser-0.3.1.1-I7US0wpvD2rF6h5zXRRyiu
depends:
    base-4.11.1.0 monoid-subclasses-0.4.6-CMjZB0x7XDI9ylTQO1SrFX
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             monoid-subclasses-0.4.6-CMjZB0x7XDI9ylTQO1SrFX=7818f39b9a3064f60d3533b60df90d47
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.3.1.1-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.3.1.1
id: incremental-parser-0.3.1.1-5LPkOelaGzo3uTC3m16YoW
key: incremental-parser-0.3.1.1-5LPkOelaGzo3uTC3m16YoW
license: GPL-3.0-only
copyright: (c) 2011-2018 Mario Blazevic
maintainer: blamario@yahoo.com
author: Mario Blazevic
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
abi: c985f18f6c098172bcdcab875a42f70c
exposed: True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
import-dirs: /usr/lib/ghc-8.4.3/site-local/incremental-parser-0.3.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/incremental-parser-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/incremental-parser-0.3.1.1
hs-libraries: HSincremental-parser-0.3.1.1-5LPkOelaGzo3uTC3m16YoW
depends:
    base-4.11.1.0 monoid-subclasses-0.4.6-CMjZB0x7XDI9ylTQO1SrFX
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             monoid-subclasses-0.4.6-CMjZB0x7XDI9ylTQO1SrFX=7818f39b9a3064f60d3533b60df90d47
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
